"""
The `load_config.py` module provides functionality to load configuration data from JSON files.
"""

import json
from pathlib import Path


def load_config_from_file(file_path: Path) -> dict:
    """
    Loads configuration data from a specified JSON file.

    Parameters
    ----------
    file_path : Path
        The path to the JSON file containing configuration data.

    Returns
    -------
    dict
        The configuration data loaded from the JSON file.

    Raises
    ------
    FileNotFoundError
        If the specified file does not exist.
    json.JSONDecodeError
        If the file contains invalid JSON.
    """
    with open(file_path, "r") as file:
        return json.load(file)
